@@ -8,7 +8,6 @@ import pylab as pl
 import sciris as sc
 from . import base as cvbase
 from . import sim as cvsim
-from . import healthsystem as cvhs
 
 
 # Specify all externally visible functions this file defines
@@ -102,6 +101,7 @@ class Scenarios(cvbase.ParsObj):
         self.reskeys = self.base_sim.reskeys
 
         # Create the results object; order is: results key, scenario, best/low/high
+        self.sims = sc.objdict()
         self.allres = sc.objdict()
         for reskey in self.reskeys:
             self.allres[reskey] = sc.objdict()
@@ -112,15 +112,14 @@ class Scenarios(cvbase.ParsObj):
         return
 
 
-    def run(self, keep_sims=False, debug=False, healthsystems=True, verbose=None):
+    def run(self, debug=False, verbose=None, **kwargs):
         '''
         Run the actual scenarios
 
         Args:
-            keep_sims (bool): whether or not to store the actual Sim objects in the Scenarios object (NB, very large)
             debug (bool): if True, runs a single run instead of multiple, which makes debugging easier
-            healthsystems (bool): whether or not to run a health systems analysis on the results
             verbose (int): level of detail to print, passed to sim.run()
+            kwargs (dict): passed to multi_run() and thence to sim.run()
 
         Returns:
             None (modifies Scenarios object in place)
@@ -158,9 +157,9 @@ class Scenarios(cvbase.ParsObj):
             if debug:
                 print('Running in debug mode (not parallelized)')
                 run_args.pop('n_runs', None) # Remove n_runs argument, not used for a single run
-                scen_sims = [single_run(scen_sim, **run_args)]
+                scen_sims = [single_run(scen_sim, **run_args, **kwargs)]
             else:
-                scen_sims = multi_run(scen_sim, **run_args) # This is where the sims actually get run
+                scen_sims = multi_run(scen_sim, **run_args, **kwargs) # This is where the sims actually get run
 
             # Process the simulations
             print_heading(f'Processing {scenkey}')
@@ -185,12 +184,8 @@ class Scenarios(cvbase.ParsObj):
                 for blh in ['best', 'low', 'high']:
                     self.allres[reskey][scenkey][blh] = scenres[blh][reskey]
 
-            if keep_sims:
-                if 'sims' not in self.allres:
-                    self.allres['sims'] = sc.objdict()
-                self.allres['sims'][scenkey] = scen_sims
-                print('Note: saving sims, which may produce a large file! Estimated to be:')
-                sc.checkmem(self.allres) # Print a warning about how big the file is likely to be
+            self.sims[scenkey] = scen_sims
+
 
 
         #%% Print statistics
@@ -202,11 +197,6 @@ class Scenarios(cvbase.ParsObj):
                     print(f'  {scenkey}: {self.allres[reskey][scenkey].best[-1]:0.0f}')
             print() # Add a blank space
 
-        # Perform health systems analysis
-        if healthsystems:
-            self.hsys = cvhs.HealthSystem(self.allres)
-            self.hsys.analyze()
-
         return
 
 
@@ -221,10 +211,10 @@ class Scenarios(cvbase.ParsObj):
             to_plot     (dict): Dict of results to plot; see default_scen_plots for structure
             do_save     (bool): Whether or not to save the figure
             fig_path    (str):  Path to save the figure
-            fig_args    (dict): Dictionary of kwargs to be passed to pl.figure                             ( )
-            plot_args   (dict): Dictionary of kwargs to be passed to pl.plot                               ( )
-            axis_args   (dict): Dictionary of kwargs to be passed to pl.subplots_adjust                    ( )
-            fill_args   (dict): Dictionary of kwargs to be passed to pl.fill_between                       ( )
+            fig_args    (dict): Dictionary of kwargs to be passed to pl.figure()
+            plot_args   (dict): Dictionary of kwargs to be passed to pl.plot()
+            axis_args   (dict): Dictionary of kwargs to be passed to pl.subplots_adjust()
+            fill_args   (dict): Dictionary of kwargs to be passed to pl.fill_between()
             as_dates    (bool): Whether to plot the x-axis as dates or time points
             interval    (int):  Interval between tick marks
             dateformat  (str):  Date string format, e.g. '%B %d'
@@ -274,14 +264,13 @@ class Scenarios(cvbase.ParsObj):
             resdata = self.allres[reskey]
 
             for scenkey, scendata in resdata.items():
+
                 pl.fill_between(self.tvec, scendata.low, scendata.high, **fill_args)
                 pl.plot(self.tvec, scendata.best, label=scendata.name, **plot_args)
-
                 pl.title(title)
                 if rk == 0:
                     pl.legend(loc='best')
 
-                sc.setylim()
                 pl.grid(grid)
                 if commaticks:
                     sc.commaticks()
@@ -312,17 +301,15 @@ class Scenarios(cvbase.ParsObj):
         return fig
 
 
-    def plot_healthsystem(self, *args, **kwargs):
-        ''' Very simple method to plot the health system results '''
-        return self.hsys.plot(*args, **kwargs)
 
-
-    def save(self, filename=None, **kwargs):
+    def save(self, filename=None, keep_sims=True, keep_people=False, **kwargs):
         '''
         Save to disk as a gzipped pickle.
 
         Args:
             filename (str or None): the name or path of the file to save to; if None, uses stored
+            keep_sims (bool): whether or not to store the actual Sim objects in the Scenarios object
+            keep_people (bool): whether or not to store the people in the Sim objects (NB, very large)
             keywords: passed to makefilepath()
 
         Returns:
@@ -336,7 +323,27 @@ class Scenarios(cvbase.ParsObj):
             filename = self.filename
         filename = sc.makefilepath(filename=filename, **kwargs)
         self.filename = filename # Store the actual saved filename
-        sc.saveobj(filename=filename, obj=self)
+
+        # Store sims seperately
+        sims = self.sims
+        self.sims = None # Remove for now
+
+        obj = sc.dcp(self) # This should be quick once we've removed the sims
+
+        if keep_sims:
+            if keep_people:
+                obj.sims = sims # Just restore the object in full
+                print('Note: saving people, which may produce a large file!')
+            else:
+                obj.sims = sc.objdict()
+                for key in sims.keys():
+                    obj.sims[key] = []
+                    for sim in sims[key]:
+                        obj.sims[key].append(sim.shrink())
+
+        sc.saveobj(filename=filename, obj=obj) # Actually save
+
+        self.sims = sims # Restore
         return filename
 
 
@@ -361,34 +368,46 @@ class Scenarios(cvbase.ParsObj):
 
 
 
-def single_run(sim, ind=0, noise=0.0, noisepar=None, verbose=None, sim_args=None, **kwargs):
+def single_run(sim, ind=0, noise=0.0, noisepar=None, verbose=None, run_args=None, sim_args=None, **kwargs):
     '''
     Convenience function to perform a single simulation run. Mostly used for
-    parallelization, but can also be used directly:
-        import covasim.cova_generic as cova
-        sim = cova.Sim() # Create a default simulation
-        sim = cova.single_run(sim) # Run it, equivalent(ish) to sim.run()
+    parallelization, but can also be used directly.
+
+    Args:
+        sim (Sim): the sim instance to be run
+        ind (int): the index of this sim
+        noise (float): the amount of noise to add to each run
+        noisepar (string): the name of the parameter to add noise to
+        verbose (int): detail to print
+        run_args (dict): arguments passed to sim.run()
+        sim_args (dict): extra parameters to pass to the sim, e.g. 'n_infected'
+        kwargs (dict): also passed to the sim
+
+    Returns:
+        sim (Sim): a single sim object with results
+
+    Example:
+        import covasim as cv
+        sim = cv.Sim() # Create a default simulation
+        sim = cv.single_run(sim) # Run it, equivalent(ish) to sim.run()
     '''
 
-    if sim_args is None:
-        sim_args = {}
-
-    new_sim = sc.dcp(sim) # To avoid overwriting it; otherwise, use
+    new_sim = sc.dcp(sim) # Copy the sim to avoid overwriting it
 
+    # Set sim and run arguments
     if verbose is None:
         verbose = new_sim['verbose']
+    sim_args = sc.mergedicts(sim_args, kwargs)
+    run_args = sc.mergedicts({'verbose':verbose}, run_args)
 
     new_sim['seed'] += ind # Reset the seed, otherwise no point of parallel runs
     new_sim.set_seed()
 
     # If the noise parameter is not found, guess what it should be
     if noisepar is None:
-        guesses = ['r_contact', 'r0', 'beta']
-        found = [guess for guess in guesses if guess in sim.pars.keys()]
-        if len(found)!=1:
-            raise KeyError(f'Cound not guess noise parameter since out of {guesses}, {found} were found')
-        else:
-            noisepar = found[0]
+        noisepar = 'beta'
+        if noisepar not in sim.pars.keys():
+            raise KeyError(f'Noise parameter {noisepar} was not found in sim parameters')
 
     # Handle noise -- normally distributed fractional error
     noiseval = noise*np.random.normal()
@@ -402,28 +421,47 @@ def single_run(sim, ind=0, noise=0.0, noisepar=None, verbose=None, sim_args=None
         print(f'Running a simulation using {new_sim["seed"]} seed and {noisefactor} noise')
 
     # Handle additional arguments
-    for key,val in kwargs.items():
+    for key,val in sim_args.items():
         print(f'Processing {key}:{val}')
         if key in new_sim.pars.keys():
             if verbose>=1:
                 print(f'Setting key {key} from {new_sim[key]} to {val}')
                 new_sim[key] = val
-            pass
         else:
             raise KeyError(f'Could not set key {key}: not a valid parameter name')
 
     # Run
-    new_sim.run(verbose=verbose)
+    new_sim.run(**run_args)
 
     return new_sim
 
 
-def multi_run(sim, n_runs=4, noise=0.0, noisepar=None, iterpars=None, verbose=None, sim_args=None, combine=False, **kwargs):
+def multi_run(sim, n_runs=4, noise=0.0, noisepar=None, iterpars=None, verbose=None, combine=False, run_args=None, sim_args=None, **kwargs):
     '''
-    For running multiple runs in parallel. Example:
-        import covid_seattle
-        sim = covid_seattle.Sim()
-        sims = covid_seattle.multi_run(sim, n_runs=6, noise=0.2)
+    For running multiple runs in parallel.
+
+    Args:
+        sim (Sim): the sim instance to be run
+        n_runs (int): the number of parallel runs
+        noise (float): the amount of noise to add to each run
+        noisepar (string): the name of the parameter to add noise to
+        iterpars (dict): any other parameters to iterate over the runs; see sc.parallelize() for syntax
+        verbose (int): detail to print
+        combine (bool): whether or not to combine all results into one sim, rather than return multiple sim objects
+        run_args (dict): arguments passed to sim.run()
+        sim_args (dict): extra parameters to pass to the sim
+        kwargs (dict): also passed to the sim
+
+    Returns:
+        if combine:
+            a single sim object with the combined results from each sim
+        else (default):
+            a list of sim objects
+
+    Example:
+        import covasim as cv
+        sim = cv.Sim()
+        sims = cv.multi_run(sim, n_runs=6, noise=0.2)
     '''
 
     # Create the sims
@@ -445,7 +483,7 @@ def multi_run(sim, n_runs=4, noise=0.0, noisepar=None, iterpars=None, verbose=No
     # Copy the simulations
     iterkwargs = {'ind':np.arange(n_runs)}
     iterkwargs.update(iterpars)
-    kwargs = {'sim':sim, 'noise':noise, 'noisepar':noisepar, 'verbose':verbose, 'sim_args':sim_args}
+    kwargs = {'sim':sim, 'noise':noise, 'noisepar':noisepar, 'verbose':verbose, 'sim_args':sim_args, 'run_args':run_args}
     sims = sc.parallelize(single_run, iterkwargs=iterkwargs, kwargs=kwargs)
 
     # Usual case -- return a list of sims
