@@ -8,8 +8,9 @@ import pytest
 import sciris as sc
 import covasim as cv
 
-doplot = 1
-
+do_plot = 1
+do_save = 0
+do_show = 1
 
 #%% Define the tests
 
@@ -47,7 +48,7 @@ def test_microsim():
     return sim
 
 
-def test_sim(doplot=False): # If being run via pytest, turn off
+def test_sim(do_plot=False, do_save=False, do_show=False): # If being run via pytest, turn off
     sc.heading('Basic sim test')
 
     # Settings
@@ -60,8 +61,8 @@ def test_sim(doplot=False): # If being run via pytest, turn off
     sim.run(verbose=verbose)
 
     # Optionally plot
-    if doplot:
-        sim.plot()
+    if do_plot:
+        sim.plot(do_save=do_save, do_show=do_show)
 
     return sim
 
@@ -70,22 +71,22 @@ def test_singlerun():
     sc.heading('Single run test')
 
     iterpars = {'beta': 0.035,
-                'incub': 8,
                 }
 
     sim = cv.Sim()
     sim['n_days'] = 20
+    sim['n'] = 1000
     sim = cv.single_run(sim=sim, **iterpars)
 
     return sim
 
 
-def test_combine(doplot=False): # If being run via pytest, turn off
+def test_combine(do_plot=False): # If being run via pytest, turn off
     sc.heading('Combine results test')
 
-    n_runs = 5
-    n = 2000
-    n_infected = 100
+    n_runs = 3
+    n = 1000
+    n_infected = 10
 
     print('Running first sim...')
     sim = cv.Sim({'n':n, 'n_infected':n_infected})
@@ -96,37 +97,39 @@ def test_combine(doplot=False): # If being run via pytest, turn off
     sim2 = cv.Sim({'n':n*n_runs, 'n_infected':n_infected*n_runs})
     sim2.run()
 
-    if doplot:
+    if do_plot:
         sim.plot()
         sim2.plot()
 
     return sim
 
 
-def test_multirun(doplot=False): # If being run via pytest, turn off
+def test_multirun(do_plot=False): # If being run via pytest, turn off
     sc.heading('Multirun test')
 
     # Note: this runs 3 simulations, not 3x3!
     iterpars = {'beta': [0.015, 0.025, 0.035],
-                'incub': [4, 5, 6],
+                'cont_factor': [0.1, 0.5, 0.9],
                 }
 
-    sim = cv.Sim() # Shouldn't be necessary, but is for now
+    sim = cv.Sim()
     sim['n_days'] = 60
+    sim['n'] = 1000
     sims = cv.multi_run(sim=sim, iterpars=iterpars)
 
-    if doplot:
+    if do_plot:
         for sim in sims:
             sim.plot()
 
     return sims
 
 
-def test_scenarios(doplot=False):
+def test_scenarios(do_plot=False):
     sc.heading('Scenarios test')
-    scens = cv.Scenarios()
+    basepars = {'n':1000}
+    scens = cv.Scenarios(basepars=basepars)
     scens.run()
-    if doplot:
+    if do_plot:
         scens.plot()
     return scens
 
@@ -140,6 +143,7 @@ def test_fileio():
     # Create and run the simulation
     sim = cv.Sim()
     sim['n_days'] = 20
+    sim['n'] = 1000
     sim.run(verbose=0)
 
     # Create objects
@@ -158,20 +162,51 @@ def test_fileio():
     return json
 
 
+def test_start_stop(): # If being run via pytest, turn off
+    sc.heading('Test starting and stopping')
+
+    pars = {'n': 1000}
+
+    # Create and run a basic simulation
+    sim1 = cv.Sim(pars)
+    sim1.run(verbose=0)
+
+    # Test start and stop
+    stop = 20
+    sim2 = cv.Sim(pars)
+    sim2.run(start=0, stop=stop, verbose=0)
+    sim2.run(start=stop, stop=None, verbose=0)
+
+    # Test that next works
+    sim3 = cv.Sim(pars)
+    sim3.initialize()
+    for n in range(sim3.npts):
+        sim3.next(verbose=0)
+    sim3.finalize()
+
+    # Compare results
+    key = 'cum_exposed'
+    assert (sim1.results[key][:] == sim2.results[key][:]).all(), 'Start-stop values do not match'
+    assert (sim1.results[key][:] == sim3.results[key][:]).all(), 'Next values do not match'
+
+    return sim2
+
+
 #%% Run as a script
 if __name__ == '__main__':
-    sc.tic()
+    T = sc.tic()
 
-    parsobj = test_parsobj()
-    sim0    = test_microsim()
-    sim1    = test_sim(doplot=doplot)
-    sim2    = test_singlerun()
-    sim3    = test_combine(doplot=doplot)
-    sims    = test_multirun(doplot=doplot)
-    scens   = test_scenarios(doplot=doplot)
-    json    = test_fileio()
+    pars  = test_parsobj()
+    sim0  = test_microsim()
+    sim1  = test_sim(do_plot=do_plot, do_save=do_save, do_show=do_show)
+    sim2  = test_singlerun()
+    sim3  = test_combine(do_plot=do_plot)
+    sims  = test_multirun(do_plot=do_plot)
+    scens = test_scenarios(do_plot=do_plot)
+    json  = test_fileio()
+    sim   = test_start_stop()
 
-    sc.toc()
+    sc.toc(T)
 
 
 print('Done.')
